==> python_sonarqube_api-2.0.4-py3-none-any.whl: sonarqube/utils/config.py <==
API_COMPONENTS_SHOW_ENDPOINT = "/api/components/show"

API_PROJECTS_SEARCH_ENDPOINT = "/api/projects/search"

API_USERS_SEARCH_ENDPOINT = "/api/users/search"
API_USER_GROUPS_SEARCH_ENDPOINT = "/api/user_groups/search"
API_USER_GROUPS_CREATE_ENDPOINT = "/api/user_groups/create"
API_USER_GROUPS_DELETE_ENDPOINT = "/api/user_groups/delete"
API_USER_GROUPS_UPDATE_ENDPOINT = "/api/user_groups/update"
API_CE_ACTIVITY_ENDPOINT = "/api/ce/activity"

API_MEASURES_COMPONENT_ENDPOINT = "/api/measures/component"

API_PROJECT_BRANCHES_LIST_ENDPOINT = "/api/project_branches/list"
API_ISSUES_SEARCH_ENDPOINT = "/api/issues/search"
API_ISSUES_ASSIGN_ENDPOINT = "/api/issues/assign"
API_QUALITYGATES_LIST_ENDPOINT = "/api/qualitygates/list"
API_QUALITYGATES_SELECT_ENDPOINT = "/api/qualitygates/select"
API_QUALITYGATES_SEARCH_ENDPOINT = "/api/qualitygates/search"
API_RULES_SEARCH_ENDPOINT = "/api/rules/search"
API_RULES_CREATE_ENDPOINT = "/api/rules/create"

API_QUALITYPROFILES_ACTIVATE_RULE_ENDPOINT = "/api/qualityprofiles/activate_rule"
API_QUALITYPROFILES_SEARCH_ENDPOINT = "/api/qualityprofiles/search"
API_QUALITYPROFILES_DELETE_ENDPOINT = "/api/qualityprofiles/delete"
API_QUALITYPROFILES_CREATE_ENDPOINT = "/api/qualityprofiles/create"
API_DUPLICATIONS_SHOW_ENDPOINT = "/api/duplications/show"

API_METRICS_SEARCH_ENDPOINT = "/api/metrics/search"
API_METRICS_TYPES_ENDPOINT = "/api/metrics/types"

API_AUTH_VALIDATE_ENDPOINT = "/api/authentication/validate"

API_FAVORITES_SEARCH_ENDPOINT = "/api/favorites/search"

API_LANGUAGES_LIST_ENDPOINT = "/api/languages/list"

API_PROJECT_BADGES_MEASURE_ENDPOINT = "/api/project_badges/measure"
API_PROJECT_LINKS_SEARCH_ENDPOINT = "/api/project_links/search"

API_PROJECT_TAGS_SEARCH_ENDPOINT = "/api/project_tags/search"
API_PROJECT_ANALYSES_DELETE_ENDPOINT = "/api/project_analyses/delete"
API_PROJECT_ANALYSES_SEARCH_ENDPOINT = "/api/project_analyses/search"

API_SERVER_VERSION_ENDPOINT = "/api/server/version"

API_USER_TOKENS_GENERATE_ENDPOINT = "/api/user_tokens/generate"
API_USER_TOKENS_REVOKE_ENDPOINT = "/api/user_tokens/revoke"
API_USER_TOKENS_SEARCH_ENDPOINT = "/api/user_tokens/search"

API_PROJECT_DUMP_EXPORT_ENDPOINT = "/api/project_dump/export"
API_PROJECT_DUMP_IMPORT_ENDPOINT = "/api/project_dump/import"


API_EDITIONS_SET_LICENSE = "/api/editions/set_license"

API_VIEWS_UPDATE = "/api/views/update"
API_VIEWS_SHOW = "/api/views/show"
API_VIEWS_LIST = "/api/views/list"

==> python_sonarqube_api-2.0.5-py3-none-any.whl: sonarqube/utils/config.py <==
API_COMPONENTS_SHOW_ENDPOINT = "/api/components/show"

API_PROJECTS_BULK_DELETE_ENDPOINT = "/api/projects/bulk_delete"
API_PROJECTS_DELETE_ENDPOINT = "/api/projects/delete"
API_PROJECTS_SEARCH_ENDPOINT = "/api/projects/search"
API_PROJECTS_CREATE_ENDPOINT = "/api/projects/create"

API_USERS_SEARCH_ENDPOINT = "/api/users/search"
API_USER_GROUPS_SEARCH_ENDPOINT = "/api/user_groups/search"
API_USER_GROUPS_CREATE_ENDPOINT = "/api/user_groups/create"
API_USER_GROUPS_DELETE_ENDPOINT = "/api/user_groups/delete"
API_USER_GROUPS_UPDATE_ENDPOINT = "/api/user_groups/update"
API_CE_ACTIVITY_ENDPOINT = "/api/ce/activity"

API_MEASURES_COMPONENT_ENDPOINT = "/api/measures/component"

API_PROJECT_BRANCHES_LIST_ENDPOINT = "/api/project_branches/list"
API_ISSUES_SEARCH_ENDPOINT = "/api/issues/search"
API_ISSUES_ASSIGN_ENDPOINT = "/api/issues/assign"
API_QUALITYGATES_LIST_ENDPOINT = "/api/qualitygates/list"
API_QUALITYGATES_SELECT_ENDPOINT = "/api/qualitygates/select"
API_QUALITYGATES_SEARCH_ENDPOINT = "/api/qualitygates/search"
API_RULES_SEARCH_ENDPOINT = "/api/rules/search"
API_RULES_CREATE_ENDPOINT = "/api/rules/create"

API_QUALITYPROFILES_ACTIVATE_RULE_ENDPOINT = "/api/qualityprofiles/activate_rule"
API_QUALITYPROFILES_SEARCH_ENDPOINT = "/api/qualityprofiles/search"
API_QUALITYPROFILES_DELETE_ENDPOINT = "/api/qualityprofiles/delete"
API_QUALITYPROFILES_CREATE_ENDPOINT = "/api/qualityprofiles/create"
API_DUPLICATIONS_SHOW_ENDPOINT = "/api/duplications/show"

API_METRICS_SEARCH_ENDPOINT = "/api/metrics/search"
API_METRICS_TYPES_ENDPOINT = "/api/metrics/types"

API_AUTH_VALIDATE_ENDPOINT = "/api/authentication/validate"

API_FAVORITES_SEARCH_ENDPOINT = "/api/favorites/search"

API_LANGUAGES_LIST_ENDPOINT = "/api/languages/list"

API_PROJECT_BADGES_MEASURE_ENDPOINT = "/api/project_badges/measure"
API_PROJECT_LINKS_SEARCH_ENDPOINT = "/api/project_links/search"

API_PROJECT_TAGS_SEARCH_ENDPOINT = "/api/project_tags/search"
API_PROJECT_ANALYSES_DELETE_ENDPOINT = "/api/project_analyses/delete"
API_PROJECT_ANALYSES_SEARCH_ENDPOINT = "/api/project_analyses/search"

API_SERVER_VERSION_ENDPOINT = "/api/server/version"

API_USER_TOKENS_GENERATE_ENDPOINT = "/api/user_tokens/generate"
API_USER_TOKENS_REVOKE_ENDPOINT = "/api/user_tokens/revoke"
API_USER_TOKENS_SEARCH_ENDPOINT = "/api/user_tokens/search"

API_PROJECT_DUMP_EXPORT_ENDPOINT = "/api/project_dump/export"
API_PROJECT_DUMP_IMPORT_ENDPOINT = "/api/project_dump/import"


API_EDITIONS_SET_LICENSE_ENDPOINT = "/api/editions/set_license"

API_VIEWS_UPDATE_ENDPOINT = "/api/views/update"
API_VIEWS_SHOW_ENDPOINT = "/api/views/show"
API_VIEWS_LIST_ENDPOINT = "/api/views/list"

API_AUDIT_LOGS_DOWNLOAD_ENDPOINT = "/api/audit_logs/download"
